# -*- coding: utf-8 -*-
import yafowil.utils


@yafowil.utils.entry_point(order=0)
def register():
    import yafowil.persistence
    import yafowil.common
    import yafowil.compound
    import yafowil.table  # noqa


# execute all register entry points. supposed to be used for widget and theme
# registration
for ep in yafowil.utils.get_entry_points('register'):
    ep.load()()


# execute all configure entry points. supposed to be used for theme
# configuration, like setting factory defaults and defining macros.
for ep in yafowil.utils.get_entry_points('configure'):
    ep.load()()                                               #pragma NO COVER



# -*- coding: utf-8 -*-
from interlude import interact
from pprint import pprint
import doctest
import lxml.etree as etree
import unittest


optionflags = \
    doctest.NORMALIZE_WHITESPACE | \
    doctest.ELLIPSIS | \
    doctest.REPORT_ONLY_FIRST_FAILURE


TESTFILES = [
    'tsf.rst',
    'utils.rst',
    'base.rst',
    'common.rst',
    'compound.rst',
    'controller.rst',
    'persistence.rst',
    'table.rst',
    'resources.rst',
]


def fxml(xml):
    et = etree.fromstring(xml)
    return etree.tostring(et, pretty_print=True)


def pxml(xml):
    print fxml(xml)


def test_suite():
    return unittest.TestSuite([
        doctest.DocFileSuite(
            filename,
            optionflags=optionflags,
            globs={'interact': interact,
                   'pprint': pprint,
                   'pxml': pxml},
        ) for filename in TESTFILES
    ])


if __name__ == '__main__':                                  #pragma NO COVER
    unittest.main(defaultTest='test_suite')                 #pragma NO COVER
